@@ -3,10 +3,13 @@ package Template::Flute;
 use strict;
 use warnings;
 
+use Scalar::Util qw/blessed/;
+
 use Template::Flute::Utils;
 use Template::Flute::Specification::XML;
 use Template::Flute::HTML;
 use Template::Flute::Iterator;
+use Template::Flute::Increment;
 use Template::Flute::Paginator;
 
 =head1 NAME
@@ -15,11 +18,11 @@ Template::Flute - Modern designer-friendly HTML templating Engine
 
 =head1 VERSION
 
-Version 0.0066
+Version 0.0080
 
 =cut
 
-our $VERSION = '0.0066';
+our $VERSION = '0.0080';
 
 =head1 SYNOPSIS
 
@@ -370,7 +373,7 @@ Returns HTML output.
 
 sub process {
 	my ($self, $params) = @_;
-	my ($dbobj, $iter, $sth, $row, $lel, %paste_pos, $query);
+	
 
 	unless ($self->{template}) {
 		$self->_bootstrap();
@@ -381,367 +384,142 @@ sub process {
 		$self->{template}->translate($self->{i18n});
 	}
 
-	# replace simple values
-	$self->_replace_values();
+	my $html = $self->_sub_process(
+		$self->{template}->{xml}, 
+		$self->{specification}->{xml}->root, 
+		$self->{'values'},
+		$self->{specification},
+		$self->{template}, 
+		);
+	my $shtml = $html->sprint;
+	return $shtml;
+}
 
-	for my $container ($self->{template}->containers()) {
-		if (exists $self->{values}) {
-			$container->set_values($self->{values});
+sub _sub_process {
+	my ($self, $html, $spec_xml,  $values, $spec, $root_template, $count) = @_;
+	my ($template);
+	# Use root spec or sub-spec
+	my $specification = $spec || $self->_bootstrap_specification(string => "<specification>".$spec_xml->sprint."</specification>");
+	
+	if($root_template){
+		$template = $root_template;
+	}
+	else {
+		$template = new Template::Flute::HTML;
+		$template->parse("<flutexml>".$html->sprint."</flutexml>", $specification);
+	}
+	
+	my $classes = $specification->{classes};
+	my ($dbobj, $iter, $sth, $row, $lel, %paste_pos, $query);
+	
+	# Replace values
+	for my $elt ( $spec_xml->descendants() ){
+		my $spec_name = $elt->{'att'}->{'name'};
+		my $spec_class = $elt->{'att'}->{'class'} ? $elt->{'att'}->{'class'} : $spec_name;
+		my $spec_id = $elt->{'att'}->{'id'};
+		my $type = $elt->tag;
+		
+		# List
+		if( $type eq 'list' or $type eq 'form'  ){
+			my $sep_copy;
+			my $iterator = $elt->{'att'}->{'iterator'};
+			
+			my $sub_spec = $elt->copy();
+			my $element_template = $classes->{$spec_class}->[0]->{elts}->[0];
+			
+			unless($element_template){
+				next;
+			}
+			
+			if ($element_template->is_last_child()) {			
+				%paste_pos = (last_child => $element_template->parent());
+			}
+			elsif ($element_template->next_sibling()) {
+				%paste_pos = (before => $element_template->next_sibling());
+			}
+			else {
+				# list is root element in the template
+				%paste_pos = (last_child => $html);
+			}
+			
+			my $records = $values->{$iterator};
+			my $list = $template->{lists}->{$spec_name};
+			my $count = 1;
+			for my $record_values (@$records){
+				
+				my $element = $element_template->copy();
+				$element = $self->_sub_process($element, $sub_spec, $record_values, undef, undef, $count);
+				
+				# Get rid of flutexml container and put it into position
+				for my $e (reverse($element->cut_children())) {
+					$e->paste(%paste_pos);
+        		}				
+
+				# Add separator
+				if ($list->{separators}) {
+				    for my $sep (@{$list->{separators}}) {
+						for my $elt (@{$sep->{elts}}) {
+						    $sep_copy = $elt->copy();
+						    $sep_copy->paste(%paste_pos);
+						    last;
+						}
+				    }
+				}	
+				$count++;		
+			}
+			$element_template->cut(); # Remove template element
+			
+			if ($sep_copy) {
+			    # Remove last separator and original one(s) in the template
+			    $sep_copy->cut();
+			    
+			    for my $sep (@{$list->{separators}}) {
+					for my $elt (@{$sep->{elts}}) {
+					    $elt->cut();
+					}
+			    }
+			}
 		}
 		
+		# Values
+		elsif( $type eq 'value' or $type eq 'param' or $type eq 'field'){
+			
+			# Use CLASS or ID if set
+			my $spec_clases = [];
+			if ($spec_id){
+				$spec_clases = $specification->{ids}->{$spec_id};
+			}
+			else {
+				$spec_clases = $classes->{$spec_class};
+			}
+			if ($spec_name eq 'label'){
+				1;
+			}
+			
+			for my $spec_class (@$spec_clases){
+				
+				# Increment count
+				$spec_class->{increment} = new Template::Flute::Increment(
+					increment => $spec_class->{increment}->{increment},
+					start => $count
+				) if $spec_class->{increment};
+				
+				$self->_replace_record($spec_name, $values, $spec_class, $spec_class->{elts});
+			}
+		}
+  	}
+	
+	for my $container ($template->containers()) {
+		$container->set_values($values) if $values;
+		
 		unless ($container->visible()) {
 		    for my $elt (@{$container->elts()}) {
 			$elt->cut();
 		    }
 		}
 	}
-	
-	# determine database queries
-	for my $list ($self->{template}->lists()) {
-		my $name;
-		
-		# check for (required) input
-		unless ($list->input($params)) {
-			die "Input missing for " . $list->name . "\n";
-		}
 
-		unless ($iter = $list->iterator()) {
-			if ($name = $list->iterator('name')) {
-				# resolve iterator name to object
-				if ($iter = $self->{specification}->iterator($name)) {
-					$list->set_iterator($iter);
-				}
-				elsif (exists $self->{iterators}->{$name}) {
-					# iterator name from method parameters
-					$iter = $list->set_iterator($self->{iterators}->{$name});
-				}
-				elsif ($self->{auto_iterators}) {
-					if (ref($self->{values}->{$name}) eq 'ARRAY') {
-						$iter = Template::Flute::Iterator->new($self->{values}->{$name});
-					}
-					else {
-						$iter = Template::Flute::Iterator->new([]);
-					}
-					$list->set_iterator($iter);
-				}
-				else {
-					die "Missing iterator object for list " . $list->name . " and iterator name $name";
-				}
-			}
-			elsif ($self->{database}) {
-				if ($query = $list->query()) {
-					$iter = $self->{database}->build($query);
-					$iter->run();
-				}
-				else {
-					die "List " . $list->name . " without iterator and database query.\n";
-				}
-			}
-			else {
-				die "List " . $list->name . " without iterator and database object.\n";
-			}
-		}
-		
-		# process template
-		$lel = $list->elt();
-
-		if ($lel->is_last_child()) {			
-			%paste_pos = (last_child => $lel->parent());
-		}
-		elsif ($lel->next_sibling()) {
-			%paste_pos = (before => $lel->next_sibling());
-		}
-		else {
-			# list is root element in the template
-			%paste_pos = (last_child => $self->{template}->{xml});
-		}
-		
-		$lel->cut();
-
-		my ($row, $sep_copy, $list_elt);
-		my $row_pos = 0;
-        
-		my ($level_last, $level_val, @level_elts, @siblings, @level_stack);
-        $level_last = 0;
-        my $level_collect_sub;
-        
-        if ($list->{sob}->{level}) {
-            # prepare function for flat trees
-            $level_collect_sub = sub {
-                my ($record, $list_elt) = @_;
-                
-                # register as sibling
-                if ($record) {
-                    $level_val =  $row->{$list->{sob}->{level}} || 0;
-                    push (@{$siblings[$level_val]}, $list_elt);
-                }
-                else {
-                    $level_val = 0;
-                }
-                
-                if ($level_val < $level_last) {
-                    # fill stack for tree manipulations
-                    for my $ll ($level_last - 1 .. $level_val) {
-                        unshift (@level_stack,
-                                 {parent => $level_elts[$ll],
-                                  children => [@{$siblings[$ll+1]}],
-                                 });
-                            
-                        $siblings[$ll+1] = [];
-                    }
-                }
-
-                if ($record) {
-                    $level_elts[$level_val] = $list_elt;
-                    $level_last = $level_val;
-                }
-            };
-        }
-
-        if ($list->{paging}) {
-            # turn iterator into paginator
-            my $page_size = $list->{paging}->{page_size} || 20;
-
-            $iter = Template::Flute::Paginator->new(iterator => $iter,
-                                                    page_size => $page_size);
-
-            if ($iter->pages > 1) {
-                my ($element_orig, $element_copy, %element_pos, $element_link,
-                    $paging_page, $paging_link, $slide_length, $element, $element_active, $paging_min, $paging_max);
-
-                $paging_page = $self->{values}->{$list->{paging}->{page_value}}  || 1;
-                $paging_link = $self->{values}->{$list->{paging}->{link_value}};
-
-                $slide_length = $list->{paging}->{slide_length};
-
-                $paging_min = 1;
-                $paging_max = $iter->pages;
-
-                if ($slide_length > 0) {
-                    # determine the page numbers to show up
-                    if ($iter->pages > $slide_length) {
-                        $paging_min = int($paging_page - $slide_length / 2);
-
-                        if ($paging_min < 1) {
-                            $paging_min = 1;
-                        }
-
-                        $paging_max = $paging_min + $slide_length - 1;
-                    }
-                }
-
-                $iter->select_page($paging_page);
-
-                for my $type (qw/first previous next last active standard/) {
-                    if ($element = $list->{paging}->{elements}->{$type}) {
-                        $element_orig = shift @{$element->{elts}};
-                        next unless $element_orig;
-
-                        # cut any other elements
-                        for my $sf (@{$element->{elts}}) {
-                            $sf->cut;
-                        }
-                    }
-                    else {
-                        next;
-                    }
-
-                    if ($element_orig->is_last_child()) {			
-                        %element_pos = (last_child => $element_orig->parent());
-                    }
-                    elsif ($element_orig->next_sibling()) {
-                        %element_pos = (before => $element_orig->next_sibling());
-                    }
-                    else {
-                        die "Neither last child nor next sibling.";
-                    }
-                   
-                    if ($element->{type} eq 'active') {
-                        $element_active = $element_orig;
-                    }
-                    elsif ($element->{type} eq 'standard') {
-                        for (1 .. $iter->pages) {
-                            next if $_ < $paging_min || $_ > $paging_max;
-
-                            if ($_ == $paging_page) {
-                                # Move active element here
-                                if ($element_active->{"flute_active"}->{rep_elt}) {
-                                    $element_active->{"flute_active"}->{rep_elt}->set_text($_);
-                                }
-                                else {
-                                    $element_active->set_text($_);
-                                }
-
-                                $element_copy = $element_active->cut;
-                                $element_copy->paste(%element_pos);
-                                next;
-                            }
-
-                            # Adjust text
-                            if ($element_orig->{"flute_$element->{name}"}->{rep_elt}) {
-                                $element_orig->{"flute_$element->{name}"}->{rep_elt}->set_text($_);
-                            }
-                            else {
-                                $element_orig->set_text($_);
-                            }
-
-                            # Adjust link
-                            if ($element_link = $element_orig->first_descendant('a')) {
-                                $self->_paging_link($element_link, $paging_link, $_);
-                            }
-
-                            # Copy HTML element
-                            $element_copy = $element_orig->copy;
-                            $element_copy->paste(%element_pos);
-                        }
-
-                        $element_orig->cut;
-                    }
-                    elsif ($element->{type} eq 'first') {
-                        if ($paging_page > 1) {
-                            # Adjust link
-                            if ($element_link = $element_orig->first_descendant('a')) {
-                                $self->_paging_link($element_link, $paging_link, 1);
-                            }
-                        }
-                        else {
-                            $element_orig->cut;
-                        }
-                    }
-                    elsif ($element->{type} eq 'last') {
-                        if ($paging_page < $iter->pages) {
-                            # Adjust link
-                            if ($element_link = $element_orig->first_descendant('a')) {
-                                $self->_paging_link($element_link, $paging_link, $iter->pages);
-                            }
-                        }
-                        else {
-                            $element_orig->cut;
-                        }
-                    }
-                    elsif ($element->{type} eq 'next') {
-                        if ($paging_page < $iter->pages) {
-                            # Adjust link
-                            if ($element_link = $element_orig->first_descendant('a')) {
-                                $self->_paging_link($element_link, $paging_link, $paging_page + 1);
-                            }
-                        }
-                        else {
-                            $element_orig->cut;
-                        }
-                    }
-                    elsif ($element->{type} eq 'previous') {
-                        if ($paging_page > 1) {
-                            # Adjust link
-                            if ($element_link = $element_orig->first_descendant('a')) {
-                                $self->_paging_link($element_link, $paging_link, $paging_page - 1);
-                            }
-                        }
-                        else {
-                            $element_orig->cut;
-                        }
-                    }
-                }
-            }
-            else {
-                # remove paging area
-                for my $paging_elt (@{$list->{paging}->{elts}}) {
-                    $paging_elt->cut;
-                }
-            }
-        }
-
-		while ($row = $iter->next()) {
-			if ($row = $list->filter($self, $row)) {
-				$list_elt = $self->_replace_record($list, 'list', $lel, \%paste_pos, $row, $row_pos);
-
-                if ($list->{sob}->{level}) {
-                    $level_collect_sub->($row, $list_elt);
-                } 
-
-       		$row_pos++;
-
-				$list->increment();
-
-				if ($list->separators()) {
-				    for my $sep (@{$list->separators}) {
-					for my $elt (@{$sep->{elts}}) {
-					    $sep_copy = $elt->copy();
-					    $sep_copy->paste(%paste_pos);
-					}
-				    }
-				}
-			}
-		}
-
-		if ($sep_copy) {
-		    # remove last separator and original one(s) in the template
-		    $sep_copy->cut();
-		    
-		    for my $sep (@{$list->separators}) {
-			for my $elt (@{$sep->{elts}}) {
-			    $elt->cut();
-			}
-		    }
-		}
-
-        # collect last element
-        if ($list->{sob}->{level}) {
-            $level_collect_sub->();
-
-            for my $lref (@level_stack) {
-                # create <ul> element and move inferior elements
-                my $ul = $lref->{parent}->insert_new_elt('last_child', 'ul');
-
-                for my $cref (@{$lref->{children}}) {
-                    $cref->move(last_child => $ul);
-                }
-            }
-        }
-
-        
-	}
-
-	for my $form ($self->{template}->forms()) {
-		$lel = $form->elt();
-
-		if ($lel->is_last_child()) {			
-			%paste_pos = (last_child => $lel->parent());
-		}
-		elsif ($lel->next_sibling()) {
-			%paste_pos = (before => $lel->next_sibling());
-		}
-		else {
-			# list is root element in the template
-			%paste_pos = (last_child => $self->{template}->{xml});
-		}
-		
-		$lel->cut();
-
-		if ($self->{auto_iterators}) {
-			for my $iter_name ($form->iterators()) {
-				if (ref($self->{values}->{$iter_name}) eq 'ARRAY') {
-					$iter = Template::Flute::Iterator->new($self->{values}->{$iter_name});
-				}
-				else {
-					$iter = Template::Flute::Iterator->new([]);
-				}
-
-				$self->{specification}->set_iterator($iter_name, $iter);
-			}
-		}
-		
-		if (keys(%{$form->inputs()}) && $form->input()) {
-			$iter = $dbobj->build($form->query());
-
-			$self->_replace_record($form, 'form', $lel, \%paste_pos, $iter->next());
-		}		
-		else {
-			$self->_replace_record($form, 'form', $lel, \%paste_pos, {});
-		}
-	}
-
-	return $self->{template}->{xml}->sprint;
+	return $template->{xml}->root();	
 }
 
 sub _paging_link {
@@ -772,10 +550,9 @@ sub _paging_link {
 }
 
 sub _replace_within_elts {
-	my ($self, $param, $rep_str, $elt_handler) = @_;
+	my ($param, $rep_str, $elt_handler, $elts) = @_;
 	my ($name, $zref);
-
-	for my $elt (@{$param->{elts}}) {
+	for my $elt (@$elts) {
 	    if ($elt_handler) {
 		$elt_handler->($elt, $rep_str);
 		next;
@@ -808,29 +585,18 @@ sub _replace_within_elts {
                     }
 			    }
 			    else {
-				$elt->set_att($zref->{rep_att}, $zref->{rep_att_orig} . $rep_str);
-			    }
-			} elsif (exists $param->{op} && $param->{op} eq 'toggle') {
-				if ($rep_str) {
+			    	$rep_str = $rep_str ? ($zref->{rep_att_orig} . $rep_str) : $zref->{rep_att_orig};
 					$elt->set_att($zref->{rep_att}, $rep_str);
-				} else {
-					$elt->del_att($zref->{rep_att});
-				}
+			    }
+			
 			} else {
 				$elt->set_att($zref->{rep_att}, $rep_str);
 			}
 		} elsif ($zref->{rep_elt}) {
 			# use provided text element for replacement
 			$zref->{rep_elt}->set_text($rep_str);
-		} else {
-            if (exists $param->{op} && $param->{op} eq 'toggle') {
-                unless ($rep_str) {
-                    $elt->cut;
-                }
-            }
-            else {
-                $elt->set_text($rep_str);
-            }
+		} else {			
+        	$elt->set_text($rep_str) if defined $rep_str;
 		}
 	}
 }
@@ -851,66 +617,69 @@ sub process_template {
 	return $self->{template};
 }
 
+
 sub _replace_record {
-	my ($self, $container, $type, $lel, $paste_pos, $record, $row_pos) = @_;
-	my ($param, $key, $filter, $rep_str, $att_name, $att_spec,
-		$att_tag_name, $att_tag_spec, %att_tags, $att_val, $class_alt, $elt_handler);
+	my ($self, $name, $values, $value, $elts) = @_;
+	my ($key, $filter, $att_name, $att_spec,
+		$att_tag_name, $att_tag_spec, %att_tags,  $elt_handler, $raw, $rep_str,);
 
-	# now fill in params
-	for $param (@{$container->params}) {
-		$key = $param->{name};
-				
-		$rep_str = $record->{$param->{field} || $key};
+		# determine value used for replacements
+		$rep_str = $self->value($value, $values);
+		#return undef if ((not defined $rep_str) and (defined $value->{target}));
+		$raw = $rep_str;
+		
+		if (exists $value->{op}) {
+            if ($value->{op} eq 'toggle') {
+                if (exists $value->{args} && $value->{args} eq 'static') {
+                    if ($rep_str) {
+                        # preserve static text, like a container
+                        return;
+                    }
+                }
 
-		if ($param->{increment}) {
-			$rep_str = $param->{increment}->value();
-		}
-				
-		if ($param->{subref}) {
-			$rep_str = $param->{subref}->($record);
-		}
-				
-		if ($param->{value}) {
-		    if ($rep_str) {
-			$rep_str = $param->{value};
+                unless ($raw) {
+                    # remove corresponding HTML elements from tree
+                    for my $elt (@$elts) {
+                        $elt->cut();
+                    }
+                    return;
+                }
+                $rep_str = '' unless defined $rep_str;
 		    }
-		    else {
-			$rep_str = '';
+		    elsif ($value->{op} eq 'hook') {
+                for my $elt (@$elts) {
+                    Template::Flute::HTML::hook_html($elt, $rep_str);
+                }
+		    }
+		    elsif (ref($value->{op}) eq 'CODE') {
+                $elt_handler = $value->{op};
 		    }
 		}
+		#debug "$name has value ";
+		#debug "'$rep_str'";
+		
+		# Template specified value if value defined
+		if ($value->{value}) {
+            if ($rep_str) {
+            	$rep_str = $value->{value};
+            }
+            else {
+            	$rep_str = '';
+            }
+        }
 
-		if ($param->{filter}) {
-			$rep_str = $self->filter($param, $rep_str);
+		if ($value->{increment}) {
+			$rep_str = $value->{increment}->value();
+			$value->{increment}->increment();
 		}
-
-		unless (defined $rep_str) {
-			$rep_str = '';
-		}
-
-		if (ref($param->{op}) eq 'CODE') {
-		    $self->_replace_within_elts($param, $rep_str, $param->{op});
+		#return undef unless defined $rep_str;
+		
+		if (ref($value->{op}) eq 'CODE') {
+		    _replace_within_elts($value, $rep_str, $value->{op}, $elts);
 		}
 		else {
-		    $self->_replace_within_elts($param, $rep_str);
+		    _replace_within_elts($value, $rep_str, $elt_handler, $elts);
 		}
-	}
-			
-	# now add to the template
-	my $subtree = $lel->copy();
-
-	# alternate classes?
-	if ($type eq 'list'
-		&& ($class_alt = $container->static_class($row_pos))) {
-	    if ($att_val = $subtree->att('class')) {
-		$subtree->set_att('class', "$att_val $class_alt");
-	    }
-	    else {
-		$subtree->set_att('class', $class_alt);	    
-	    }
-	}
-
-	$subtree->paste(%$paste_pos);
-    return $subtree;
 }
 
 =head2 filter ELEMENT VALUE
@@ -989,10 +758,11 @@ Returns the value for NAME.
 =cut
 
 sub value {
-	my ($self, $value) = @_;
-	my ($raw_value, $ref_value, $rep_str);
+	my ($self, $value, $values) = @_;
+	my ($raw_value, $ref_value, $rep_str, $record_is_object, $key);
 
-	$ref_value = $self->{values};
+	$ref_value = $values;
+	$record_is_object = defined blessed $ref_value;
 	
 	if ($self->{scopes}) {
 		if (exists $value->{scope}) {
@@ -1016,7 +786,7 @@ sub value {
 		%args = (template_file => $include_file,
 			 auto_iterators => $self->{auto_iterators},
              filters => $self->{filters},
-			 values => $self->{values});
+			 values => $value->{field} ? $self->{values}->{$value->{field}} : $self->{values});
 		
 		$raw_value = Template::Flute->new(%args)->process();
 	}
@@ -1043,11 +813,13 @@ sub value {
             }
         }
         else {
-            $raw_value = $ref_value->{$value->{field}};
+        	$key = $value->{field};
+            $raw_value = $record_is_object ? $ref_value->$key : $ref_value->{$key};
         }
 	}
 	else {
-		$raw_value = $ref_value->{$value->{name}};
+       	$key = $value->{name};
+        $raw_value = $record_is_object ? $ref_value->$key : $ref_value->{$key};
 	}
 
 	if ($value->{filter}) {
@@ -1064,87 +836,6 @@ sub value {
 	return $rep_str;
 }
 
-sub _replace_values {
-	my ($self) = @_;
-	my ($value, $raw, $rep_str, @elts, $elt_handler);
-
-	for my $value ($self->{template}->values()) {
-		@elts = @{$value->{elts}};
-        $elt_handler = undef;
-
-        # check if we need an iterator for this value
-    	if ($self->{auto_iterators} && $value->{iterator}) {
-            my ($iter_name, $iter);
-
-            $iter_name = $value->{iterator};
-
-            unless ($self->{specification}->iterator($iter_name)) {
-                if (ref($self->{values}->{$iter_name}) eq 'ARRAY') {
-                    $iter = Template::Flute::Iterator->new($self->{values}->{$iter_name});
-                }
-                else {
-                    $iter = Template::Flute::Iterator->new([]);
-                }
-
-                $self->{specification}->set_iterator($iter_name, $iter);
-            }
-        }
-
-		# determine value used for replacements
-		($raw, $rep_str) = $self->value($value);
-
-		if (exists $value->{op}) {
-            if ($value->{op} eq 'append' && ! $value->{target}) {
-                $elt_handler = sub {
-                    my ($elt, $str) = @_;
-
-                    $elt->set_text($elt->text_only . $str);
-                };
-            }
-		    elsif ($value->{op} eq 'toggle') {
-                if (exists $value->{args} && $value->{args} eq 'static') {
-                    if ($rep_str) {
-                        # preserve static text
-                        next;
-                    }
-                }
-                elsif ($rep_str) {
-                    for my $elt (@elts) {
-                        $elt->set_text($rep_str);
-                        next;
-                    }
-                }
-
-                unless ($raw) {
-                    # remove corresponding HTML elements from tree
-                    for my $elt (@elts) {
-                        $elt->cut();
-                    }
-                    next;
-                }
-		    }
-		    elsif ($value->{op} eq 'hook') {
-                for my $elt (@elts) {
-                    Template::Flute::HTML::hook_html($elt, $rep_str);
-                }
-                next;
-		    }
-		    elsif (ref($value->{op}) eq 'CODE') {
-                $elt_handler = $value->{op};
-		    }
-		}
-		else {
-			$rep_str = $self->value($value);
-		}
-
-		unless (defined $rep_str) {
-			$rep_str = '';
-		}
-
-		$self->_replace_within_elts($value, $rep_str, $elt_handler);
-	}
-}
-
 =head2 set_values HASHREF
 
 Sets hash reference of values to be used by the process method.
@@ -1646,7 +1337,8 @@ L<http://search.cpan.org/dist/Template-Flute/>
 Thanks to David Previous (bigpresh) for writing a much clearer introduction for
 Template::Flute.
 
-Thanks to Grega Pompe for a documentation fix.
+Thanks to Grega Pompe for proper implementation of nested lists and
+a documentation fix.
 
 Thanks to Ton Verhagen for being a big supporter of my projects in all aspects.
 
